package jp.co.powerbeans.common.chart;

import java.awt.Font;

import org.apache.commons.beanutils.BeanUtils;
import org.eclipse.swt.widgets.Item;
import org.jfree.chart.ChartFactory;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.plot.PiePlot;
import org.jfree.chart.plot.PlotOrientation;
import org.jfree.data.category.CategoryDataset;
import org.jfree.data.category.DefaultCategoryDataset;
import org.jfree.data.general.DefaultPieDataset;
import org.jfree.data.general.PieDataset;

/**
 * どのようなシステムにも利用可能なChartUtil
 * @author amonden
 *
 */
public class ChartUtil {

  public static JFreeChart createPieChartByBeans(String title, Object[] objs, String name_prop, String val_prop) {
    return createPieChartByBeans(title, objs, new String[]{name_prop}, val_prop);
  }

  public static JFreeChart createPieChartByBeans(String title, Object[] objs, String[] name_props, String val_prop) {
        DefaultPieDataset dataset = createDataset(objs, name_props, val_prop);
        JFreeChart chart = ChartFactory.createPieChart(
                title,  // chart title
                dataset,             // data
                true,               // include legend
                true,
                true
            );

            PiePlot plot = (PiePlot) chart.getPlot();
            plot.setSectionOutlinesVisible(false);
            plot.setLabelFont(new Font("SansSerif", Font.PLAIN, 12));
            plot.setNoDataMessage("データがありません");
            plot.setCircular(false);
            plot.setLabelGap(0.02);
            return chart;
    }

  private static DefaultPieDataset createDataset(Object[] objs, String[] name_props, String val_prop)  {
    try {
      DefaultPieDataset dataset = new DefaultPieDataset();
      
      for (int i = 0; i < objs.length; i++) {
        StringBuffer label_buf = new StringBuffer();
        for (int j = 0; j < name_props.length; j++) {
          if (j > 0) {
            label_buf.append(" ");
          }
          label_buf.append(BeanUtils.getProperty(objs[i], name_props[j]));
        }
        String strval = BeanUtils.getProperty(objs[i], val_prop);
        double val = 0;
        if (strval != null && strval.length() > 0) {
          String eval = strval.replace("%","").replace("-","");
          if (eval.length() == 0) {
            eval = "0";
          }
          val = Double.parseDouble(eval);
        }
        dataset.setValue(label_buf.toString(), val);
      }
      return dataset;
    } catch (Exception e) {
      throw new RuntimeException(e);
    }
  }


  private static CategoryDataset createBarDataset(Object[] objs, String[] name_props, String val_prop, Comparable data_name)  {
    try {
      
//      DefaultCategoryDataset dataset = new DefaultCategoryDataset();
      double[] vals = new double[objs.length];
      DefaultCategoryDataset dataset = new DefaultCategoryDataset();
      
      for (int i = 0; i < objs.length; i++) {
        StringBuffer label_buf = new StringBuffer();
        for (int j = 0; j < name_props.length; j++) {
          if (j > 0) {
            label_buf.append(" ");
          }
          label_buf.append(BeanUtils.getProperty(objs[i], name_props[j]));
        }
        String strval = BeanUtils.getProperty(objs[i], val_prop);
        double val = 0;
        if (strval != null && strval.length() > 0) {
          String eval = strval.replace("%","").replace("-","");
          if (eval.length() == 0) {
            eval = "0";
          }
          val = Double.parseDouble(eval);
        }
        vals[i] = val;
        dataset.addValue(val, data_name, label_buf.toString());
      }
      
////      CategoryDataset dataset = DatasetUtilities.createCategoryDataset("RowKey ", "ColKey ", new double[][]{vals});
//      for(int i=0;i<vals.length;i++){
////        Item item = (Item)items.get(i);
////        String series = item.getLogicalName();
////        int rowcount = item.getSize();
////        for(int l=0;l<rowcount;l++){
////          dataset.addValue(item.getDouble(l), series,  l + " 行");
////        }
//      }
      
      return dataset;
    } catch (Exception e) {
      throw new RuntimeException(e);
    }
  }
  public static JFreeChart createDummyChart() {
    return createChart(createDataset());
  }
  

  public static JFreeChart createBarChartByBeans(String title, Object[] objs, String[] name_props, String val_prop, Comparable data_name) {
    CategoryDataset dataset = createBarDataset(objs, name_props, val_prop, data_name);
    JFreeChart chart = ChartFactory.createBarChart(
            title,  // chart title
            "player",
            null,
            dataset,             // data
            PlotOrientation.HORIZONTAL,
            true,               // include legend
            true,
            true
        );

//        PiePlot plot = (PiePlot) chart.getPlot();
//        plot.setSectionOutlinesVisible(false);
//        plot.setLabelFont(new Font("SansSerif", Font.PLAIN, 12));
//        plot.setNoDataMessage("データがありません");
//        plot.setCircular(false);
//        plot.setLabelGap(0.02);
        return chart;
}
  /**
     * Creates a sample dataset.
     * 
     * @return A sample dataset.
     */
    private static PieDataset createDataset() {
        DefaultPieDataset dataset = new DefaultPieDataset();
        dataset.setValue("One", new Double(43.2));
        dataset.setValue("Two", new Double(10.0));
        dataset.setValue("Three", new Double(27.5));
        dataset.setValue("Four", new Double(17.5));
        dataset.setValue("Five", new Double(11.0));
        dataset.setValue("Six", new Double(19.4));
        return dataset;        
    }
    
    /**
     * Creates a chart.
     * 
     * @param dataset  the dataset.
     * 
     * @return A chart.
     */
    private static JFreeChart createChart(PieDataset dataset) {
        
        JFreeChart chart = ChartFactory.createPieChart(
            "Pie Chart Demo 1",  // chart title
            dataset,             // data
            true,               // include legend
            true,
            false
        );

        PiePlot plot = (PiePlot) chart.getPlot();
        plot.setSectionOutlinesVisible(false);
        plot.setLabelFont(new Font("SansSerif", Font.PLAIN, 12));
        plot.setNoDataMessage("No data available");
        plot.setCircular(false);
        plot.setLabelGap(0.02);
        return chart;
    }
  
}
