package jp.co.powerbeans.common.swt;


import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Layout;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Table;
import org.eclipse.swt.widgets.TableColumn;
import org.eclipse.swt.widgets.TableItem;
import org.eclipse.swt.widgets.Text;

/**
 * SwtControlのUtilクラス.
 * 主にcomponentの生成を行う
 * @author amonden
 */
public final class PBControlUtil {

	
	/**
	 * コンストラクタ
	 */
	private PBControlUtil() {
		super();
	}

	/**
	 * 基本的なTableを生成して返す.
	 * cols と wids の配列サイズが同一であること.
	 * @param composit 親composit
	 * @param cols 列名配列
	 * @param wids 列幅配列
	 * @param height 高さ
	 * @return 生成したTable
	 */
	public static Table createSimpleTable(Composite composit, String[] cols, int[] wids, int colspan, int height) {
		ChkConvSwt.assertEquals(cols.length, wids.length);
		// テーブルの作成
		Table table = new Table(composit, SWT.MULTI | SWT.FULL_SELECTION
				| SWT.BORDER);
		GridData tableGrid = new GridData();
		tableGrid.horizontalAlignment = GridData.FILL;
		tableGrid.verticalAlignment = GridData.FILL;
		tableGrid.grabExcessHorizontalSpace = true;
		tableGrid.grabExcessVerticalSpace = true;
    tableGrid.horizontalSpan = colspan;
		tableGrid.minimumHeight = height;
		table.setLayoutData(tableGrid);
		// 線を表示する
		table.setLinesVisible(true);
		// ヘッダを可視にする
		table.setHeaderVisible(true);
		// 列のヘッダの設定
		for (int i = 0; i < cols.length; i++) {
			TableColumn col = new TableColumn(table, SWT.LEFT);
			col.setText(cols[i]);
			col.setWidth(wids[i]);
		}

		return table;
	}

  /**
   * 基本的なTableを生成して返す.
   * cols と wids の配列サイズが同一であること.
   * @param composit 親composit
   * @param cols 列名配列
   * @param wids 列幅配列
   * @param height 高さ
   * @return 生成したTable
   */
  public static Table createSimpleTable(Composite composit, String[] cols, int[] wids, int height) {
    return createSimpleTable(composit, cols, wids, 1, height);
  }

	/**
	 * 基本的なButtonを生成して返す.
	 * @param composit 親composit
	 * @param label ラベル
	 * @param cmd 実行コマンド
	 * @return 生成したButton
	 */
	public static Button createSimpleButton(PBComposite composit, String label, String cmd) {
		return createSimpleButton(composit, label, cmd, null);
	}
	
	/**
	 * 基本的なButtonを生成して返す.
	 * @param composit 親composit
	 * @param label ラベル
	 * @param cmd 実行コマンド
	 * @param args 実行メソッドに渡す引数値
	 * @return 生成したButton
	 */
	public static Button createSimpleButton(PBComposite composit, String label, String cmd, Object[] args) {
		GridData gridData = new GridData();
		Button button = new Button(composit, SWT.NONE);
		button.setText(label);
    gridData.horizontalAlignment = SWT.FILL;
    gridData.grabExcessHorizontalSpace = true;
		button.setLayoutData(gridData);
		button.addSelectionListener(new CmdSelectionAdapter(composit, cmd, args));

		return button;
	}
	/**
	 * 基本的なButtonを生成して返す.
	 * @param composit 親composit
	 * @param label ラベル
	 * @param cmd 実行コマンド
	 * @return 生成したButton
	 */
	public static Button createSimpleButton(Composite composit, String label, String cmd) {
		return createSimpleButton(composit, label, cmd, null);
	}
	
	/**
	 * 基本的なButtonを生成して返す.
	 * @param composit 親composit
	 * @param label ラベル
	 * @param cmd 実行コマンド
	 * @param args 実行メソッドに渡す引数値
	 * @return 生成したButton
	 */
	public static Button createSimpleButton(Composite composit, String label, String cmd, Object[] args) {
		GridData gridData = new GridData();
		Button button = new Button(composit, SWT.NONE);
		button.setText(label);
		button.setLayoutData(gridData);
		gridData.horizontalAlignment = SWT.FILL;
		gridData.grabExcessHorizontalSpace = true;
//		button.addSelectionListener(new CmdSelectionAdapter(composit, cmd, args));

		return button;
	}

  /**
   * table に data の行を最終行に追加
   * @param table Table
   * @param data 追加する行の列ごとのデータ
   * @param obj 
   */
  public static void addRow(Table table, String[] data) {
    addRow(table, data, null);
  }
  
  /**
   * table に data の行を最終行に追加
   * @param table Table
   * @param data 追加する行の列ごとのデータ
   * @param obj 
   */
  public static void addRow(Table table, String[] data, Object obj) {
        TableItem item = new TableItem(table, SWT.NULL);
        if (obj != null) {
          item.setData(obj);
        }
        item.setText(data);
  }
  
	/**
	 * table に data の行を先頭行に追加
	 * @param table Table
	 * @param data 追加する行の列ごとのデータ
	 */
	public static void insertRowTop(Table table, String[] data, Object obj) {
		insertRow(table, data, 0, obj);
	}

	/**
	 * table に data の行を index 行に追加 (先頭 = 0)
	 * @param table Table 
	 * @param data 追加する行の列ごとのデータ
	 * @param index 挿入先
	 * @param obj 
	 */
	public static void insertRow(Table table, String[] data, int index, Object obj) {
        TableItem item = new TableItem(table, SWT.NULL, index);
        if (obj != null) {
          item.setData(obj);
        }
        item.setText(data);
	}

	/**
	 * ラベルを作成
	 * @param composit 親composit
	 * @param label ラベル
	 * @param hstyle 水平スタイル
	 * @param vstyle 垂直スタイル
	 * @return 生成したLabel
	 */
	public static Label createLabel(Composite composit, String label, int hstyle, int vstyle) {
		org.eclipse.swt.widgets.Label l = new org.eclipse.swt.widgets.Label(
				composit, hstyle);
		GridData gridData = new GridData();
		l.setText(label);

		gridData.horizontalAlignment = hstyle;
		gridData.verticalAlignment = vstyle;
		gridData.grabExcessHorizontalSpace = true;
		l.setLayoutData(gridData);
		return l;
	}

	/**
	 * ラベルを作成.vstyle = SWT.BEGINNING
	 * @param composit 親composit
	 * @param label ラベル
	 * @param hstyle 水平スタイル
	 * @return 生成したLabel
	 */
	public static Label createLabel(Composite composit, String label, int hstyle) {
		return createLabel(composit, label, hstyle, SWT.BEGINNING);
	}
	
	/**
	 * ラベルを作成.hstyle=SWT.CENTER, vstyle=SWT.CENTER
	 * @param composit 親composit
	 * @param label ラベル
	 * @return 生成したLabel
	 */
	public static Label createLabel_hvcenter(Composite composit, String label) {
		return createLabel(composit, label, SWT.CENTER, SWT.CENTER);
	}
	
	/**
	 * ラベルを作成. hstyle=SWT.LEFT, vstyle=SWT.BEGINNING
	 * @param composit 親composit
	 * @param label ラベル
	 * @return 生成したLabel
	 */
	public static Label createLabel_left(Composite composit, String label) {
		return createLabel(composit, label, SWT.LEFT);
	}
	/**
	 * ラベルを作成. hstyle=SWT.RIGHT, vstyle=SWT.BEGINNING
	 * @param composit 親composit
	 * @param label ラベル
	 * @return 生成したLabel
	 */
	public static Label createLabel_right(Composite composit, String label) {
		return createLabel(composit, label, SWT.RIGHT);
	}

	/**
	 * menu にセパレータを追加
	 * @param menu Menu
	 */
	public static void addSeparator(Menu menu) {
		new MenuItem(menu, SWT.SEPARATOR);
	}

	/**
	 * 部品を複数(たて1列)配置できるCompositeを生成
	 * @param 親shell
	 * @return composite
	 */
	public static Composite createNRow1ColComposit(Composite composite) {
		Composite comp = new Composite(composite, SWT.NO_FOCUS | SWT.EMBEDDED);
//		Composite comp = new Composite(shell, SWT.NO_FOCUS);
		comp.setLayout(new GridLayout(1, true));
		GridData compGrid = new GridData();
		compGrid.horizontalAlignment = GridData.FILL;
		compGrid.verticalAlignment = GridData.FILL;
		compGrid.grabExcessHorizontalSpace = true;
		compGrid.grabExcessVerticalSpace = true;
		comp.setLayoutData(compGrid);
		return comp;
	}

	/**
	 * 部品を複数(たて2列)配置できるCompositeを生成
	 * 
	 * @param 親shell
	 * @return composite
	 */
	public static Composite createNRow2ColComposit(Composite composite) {
		Composite comp = new Composite(composite, SWT.NO_FOCUS | SWT.VERTICAL);
		comp.setLayout(new GridLayout(2, true));
		GridData compGrid = new GridData();
		compGrid.horizontalAlignment = GridData.FILL;
		compGrid.verticalAlignment = GridData.FILL;
		compGrid.grabExcessHorizontalSpace = true;
		compGrid.grabExcessVerticalSpace = true;
		comp.setLayoutData(compGrid);
		return comp;
	}

	/**
	 * 部品を複数(col列)配置できるCompositeを生成
	 * 
	 * @param 親shell
	 * @return composite
	 */
	public static Composite createNRowNColComposit(Composite composite, int col) {
		Composite comp = new Composite(composite, SWT.NO_FOCUS);
		comp.setLayout(new GridLayout(col, true));
		GridData compGrid = new GridData();
		compGrid.horizontalAlignment = GridData.FILL;
		compGrid.verticalAlignment = GridData.FILL;
		compGrid.grabExcessHorizontalSpace = true;
		compGrid.grabExcessVerticalSpace = true;
		comp.setLayoutData(compGrid);
		return comp;
	}

	/**
	 * shellにテキストボックスを追加
	 * @param comp
	 * @return テキストボックス
	 */
	public static Text addTextBox(Composite comp) {
		Text text = new Text(comp, SWT.SINGLE | SWT.BORDER);
		GridData gridData = new GridData();
		gridData.horizontalAlignment = GridData.FILL;
		gridData.verticalAlignment = SWT.BEGINNING;
		gridData.grabExcessHorizontalSpace = true;
		text.setLayoutData(gridData);

		return text;
	}

	/**
	 * 文字列幅のボタンを追加
	 * @param shell
	 * @param label ラベル
	 * @return Button
	 */
	public static Button addSimpleButton(Composite comp, String label) {
		
		GridData gridData = new GridData();
		Button button = new Button(comp, SWT.NONE);
		button.setText(label);
		button.setLayoutData(gridData);
		gridData.horizontalAlignment = SWT.FILL;
		gridData.grabExcessHorizontalSpace = true;

		return button;
	}

	/**
	 * ラジオボタンを追加 
	 * @param shell
	 * @param labels
	 * @param vals
	 * @return
	 */
	public static Button[] addRadioButtons(Shell shell, String[] labels, int[] vals) {
		Button[] bnts = new Button[labels.length];
		
		for (int i = 0; i < bnts.length; i++) {
			GridData gridData = new GridData();
			Button button = new Button(shell, SWT.RADIO);
			button.setText(labels[i]);
			button.setLayoutData(gridData);
			gridData.horizontalAlignment = SWT.FILL;
			gridData.grabExcessHorizontalSpace = true;
			button.setData("" + vals[i]);
			bnts[i] = button;
		}
		return bnts;
	}

	/**
	 * コンボを作成
	 * @param shell 親shell
	 * @param style スタイル
	 * @return 生成コンボ
	 */
	public static Combo createComboBox(Composite composit, int style) {
		GridData gridData = new GridData();
		Combo combo = new Combo(composit, SWT.BEGINNING | SWT.TOP | style);

		gridData.heightHint = 30;
		gridData.horizontalAlignment = SWT.LEFT;
//		gridData.horizontalAlignment = SWT.FILL;
		gridData.verticalAlignment = SWT.BEGINNING;
//		gridData.grabExcessHorizontalSpace = true;
//		gridData.grabExcessVerticalSpace = true;
		combo.setLayoutData(gridData);
		return combo;
	}

	/**
	 * コンボを作成
	 * @param shell 親shell
	 * @param style スタイル
	 * @return 生成コンボ
	 */
	public static Combo createComboBoxReadOnly(Composite composit) {
		return createComboBox(composit, SWT.READ_ONLY);
	}

	/**
	 * コンボを作成
	 * @param shell 親shell
	 * @param style スタイル
	 * @return 生成コンボ
	 */
	public static Combo createComboBoxReadOnly(Composite composit, int style) {
		return createComboBox(composit, SWT.READ_ONLY | style);
	}

//	/**
//	 * コンボを作成
//	 * @param shell 親shell
//	 * @param style スタイル
//	 * @return コンボ
//	 */
//	public static Combo createComboBox(Composite composit, int style) {
//		return createComboBox(composit.getShell(), style);
//	}
	
	/**
	 * グリッドレイアウトを指定
	 * @param shell 指定するShell
	 * @param col 列数
	 */
	public static void setGridLayout(Shell shell, int col) {
		GridLayout layout = new GridLayout(col, true);
		layout.makeColumnsEqualWidth = false;
		shell.setLayout(layout);
	}

	/**
	 * グリッドレイアウトを指定
	 * @param composit 指定するShell
	 * @param col 列数
	 */
	public static void setGridLayout(Composite composit, int col) {
		setGridLayout(composit.getShell(), col);
	}

	/**
	 * Groupを生成
	 * @param composit 親 
	 * @param label ラベル
	 * @param col 列スパン数
	 * @return Group
	 */
	public static Group createGroupChadowEthedOut(Composite composit, String label, int col, int horAlign) {
    return createGroupChadowEthedOut(composit, label, col, horAlign, true);
	}

  /**
   * Groupを生成
   * @param composit 親 
   * @param label ラベル
   * @param col 列スパン数
   * @param equal_width 列幅を同じにするかどうか
   * @return Group
   */
  public static Group createGroupChadowEthedOut(Composite composit, String label, int col, int horAlign, boolean equal_width) {
    Group g = new Group(composit, SWT.SHADOW_ETCHED_OUT  | SWT.EMBEDDED);
    g.setText(label);
    GridData gridData = new GridData();
    gridData.horizontalAlignment = horAlign;
    gridData.grabExcessHorizontalSpace = true;
    g.setLayoutData(gridData);
    
    GridLayout layout = new GridLayout(col, true);
    layout.makeColumnsEqualWidth = equal_width;
    g.setLayout(layout);
    
    return g;
  }

	/**
	 * Groupを生成
	 * @param composit 親 
	 * @param label ラベル
	 * @param col 列スパン数
	 * @return Group
	 */
	public static Group createGroupChadowEthedOut_BEGIN(Composite composit, String label, int col, boolean equal_width) {
		return createGroupChadowEthedOut(composit, label, col, SWT.FILL, equal_width);
	}

	/**
	 * Groupを生成
	 * @param composit 親 
	 * @param label ラベル
	 * @param col 列スパン数
	 * @return Group
	 */
	public static Group createGroupChadowEthedOut_FILL(Composite composit, String label, int col, boolean equal_width) {
		return createGroupChadowEthedOut(composit, label, col, SWT.FILL, equal_width);
	}
	
	/**
	 * 空ラベルをnum個追加
	 * @param composit コンポジット
	 * @param num 個数
	 */
	public static void createLabelEmpty(Composite composit, int num) {
		for (int i = 0; i < num; i++) {
			PBControlUtil.createLabel_left(composit, "");
		}
	}

	/**
	 * コンポジットのサイズを指定する
	 * @param comp コンポジット
	 * @param width 幅
	 * @param height 高さ
	 */
	public static void setSize(Composite comp, int width, int height) {
		GridData gridData = (GridData) comp.getLayoutData();
		gridData.widthHint = width;
		gridData.heightHint = height;
		comp.setLayoutData(gridData);
	}

	/**
	 * comboの先頭行を選択
	 * @param combo コンボ
	 */
	public static void selectTop(Combo combo) {
		if (combo != null && combo.getItemCount() > 0) {
			combo.select(0);
		}
	}

}
