package jp.co.powerbeans.vbscore.swt;

import java.util.Date;

import jp.co.powerbeans.common.swt.ChkConvSwt;
import jp.co.powerbeans.vbscore.CMD;
import jp.co.powerbeans.vbscore.Msg;
import jp.co.powerbeans.vbscore.db.DBUtil;
import jp.co.powerbeans.vbscore.logic.DocumentMgr;
import jp.co.powerbeans.vbscore.logic.ScoreMgr;
import jp.co.powerbeans.vbscore.model.Team;
import jp.co.powerbeans.vbscore.model.TeamParGameAnalyze;

import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Table;
import org.eclipse.swt.widgets.Text;

/**
 * 試合別チーム分析画面
 * @author amonden
 *
 */
public class AnalayzeTeamParGameSwt extends PBSwt {

	/**
	 * 結果表示テーブル
	 */
	private Table table;
	/**
	 * チーム選択コンボ
	 */
	private Combo teamCombo;
	/**
	 * 開始日
	 */
	private Text fromDate;
	/**
	 * 終了日
	 */
	private Text toDate;
//	private Button outputGraphButton;

	/**
	 * 列数
	 */
	static final int COLS = 8;
	/**
	 * 列幅
	 */
	static final int COLS_WIDTH = 100;
	/**
	 * ウィンドウ幅
	 */
	static final int WINDOW_WIDTH = COLS * COLS_WIDTH;
	/**
	 * ウィンドウ高さ
	 */
	static final int WINDOW_HEIGTH = 600;

	/**
	 * タイトル
	 */
	private static final String TITLE = Msg.getAnalyzeTeamplayPerGame();
	/**
	 * トップレベルメニュー ("出力")
	 */
	private static final String[] MENU_LABELS1 = {Msg.getMenuOutput()};
	/**
	 * サブレベルメニュー ("HTML")
	 */
	private static final String[][] MENU_LABELS2 = {
		{Msg.getMenuHtml()
			}
	};
	/**
	 * サブレベルメニューコマンド ("HTML出力")
	 */
	private static final String[][] MENU_CMDS = {
		{CMD.OUTPUT_HTML 
			}
	};
	/**
	 * table列名
	 */
	private static final String[] TABLE_COLS = {Msg.getId(), Msg.getGameDate(), Msg.getCompeName(), Msg.getGameName(), Msg.getTargetVs(), Msg.getSet(), Msg.getPlay(), Msg.getResult(), Msg.getTimes(), Msg.getPercent()};
	/**
	 * table表示プロパティ名
	 */
	private static final String[] TABLE_MODEL_COLS = new String[]{"gameId", "gameDate", "compeName", "gameName", "vsTeamName", "setNum", "actionName", "actionResultName", "times", "per"};
	/**
	 * table列幅
	 */
	private static final int[] TABLE_COL_WIDTHS = {30, 80,80,70,70, 70,80,80,50,30};

	/**
	 * コンストラクタ
	 */
	public AnalayzeTeamParGameSwt() {
		super();
		initialize();
	}	
	
	/**
	 * 初期化
	 */
	private void initialize() {
		createSShell(TITLE, WINDOW_WIDTH, WINDOW_HEIGTH, true);
		setGridLayout(8);
		createItems();
		createMenu();
	}

	/**
	 * Item作成
	 */
	private void createItems() {
		addLabels(COLS);
		
		// チーム選択コンボ
		setHorizontalSpan(addLabel_right(Msg.getTargetTeam()), 2);
		this.teamCombo = addComboBoxByModel(Team.class, "teamName", CMD.SEL_CHANGE);
		setHorizontalSpan(this.teamCombo, 4);
		selectTop(this.teamCombo);
		addLabels(2);
		
		// 対象期間
		setHorizontalSpan(addLabel_right(Msg.getTargetGameDateSpan()), 2);
		this.fromDate = addTextBox("fromDate");
		addLabel_hvcenter(Msg.getChilda());
		this.toDate = addTextBox("toDate");
		
		addLabels(1);
		addSimpleButton(Msg.getSearchW(), CMD.SEARCH);
		addLabels(1);
    // FIXME 1.2 推移グラフ出力機能
//		this.outputGraphButton = addSimpleButton(Msg.getOutputChangeGraph(), CMD.OUTPUT_HISTGRAPH);
		
		// FIXME 1.2 検索直後に基本データ（セット率,勝率,総得点,総失点,等をテーブルに表示)
		
		// 詳細テーブル作成
		createTable();
	}

	/**
	 * table生成
	 */
	private void createTable() {
		if (table == null) {
			table = addSimpleTable(TABLE_COLS, TABLE_COL_WIDTHS, 200);
			setHeight(table, 400);
			setHorizontalSpan(table, COLS);
		}
	}

	/**
	 * 分析結果からtableを再表示
	 * @param ta 試合別チーム分析結果
	 */
	private void updateTable(TeamParGameAnalyze[] ta) {
		this.table.removeAll();
		addTable(ta);
	}

	/**
	 * 分析結果をtableに追加
	 * @param ta 試合別チーム分析結果
	 */
	private void addTable(TeamParGameAnalyze[] ta) {
		DBUtil.modelsToSwtTable(table, DBUtil.modelsToStrings(ta, TABLE_MODEL_COLS));
	}

	/**
	 * メニュー作成
	 */
	private void createMenu() {
		create2LayerMenu(MENU_LABELS1, MENU_LABELS2, MENU_CMDS);
	}
	
	/**
	 * HTML出力メニュー選択時
	 */
	public void cmdOutput_html() {
		int team_id = Integer.parseInt(ChkConvSwt.getSelectObjectPK(this.teamCombo));
		DocumentMgr.outputAnalyzeTeamParGame(this.sShell, team_id, this.table);
	}
	
	/**
	 * 検索ボタン選択時
	 */
	public void cmdSearch() {
		TeamParGameAnalyze[] ta = analyzeSearch();
		
		// 更新
		updateTable(ta);
	}

	private TeamParGameAnalyze[] analyzeSearch() {
		// 検索条件取得
		int team_id = Integer.parseInt(ChkConvSwt.getSelectObjectPK(this.teamCombo));
		Date from_dt = ChkConvSwt.getDate(this.fromDate.getText());
		Date to_dt = ChkConvSwt.getDate(this.toDate.getText());

		// 検索開始
		// 1. チーム
		TeamParGameAnalyze[] ta = ScoreMgr.analyzeSearchTeamPerGameSet(team_id, from_dt, to_dt);
		return ta;
	}
	
	/**
	 * ヒストグラフ出力
	 */
	public void cmdOutput_histgraph() {
		TeamParGameAnalyze[] ta = analyzeSearch();

		// FIXME 主要パラメータを折れ線グラフにして表示
		
//		// 結果をテーブル、グラフ表示
//		new MiniPieChartSwt(VBChartUtil.createPlayerRankingPieChart(team, player_ranking, ranking_def)).show(); 
	}

}
