package jp.co.powerbeans.vbscore.swt;


import java.io.IOException;

import jp.co.powerbeans.vbscore.CMD;
import jp.co.powerbeans.vbscore.Msg;
import jp.co.powerbeans.vbscore.db.DBManager;

import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Rectangle;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Group;

/**
 * メインメニュー画面
 * @author amonden
 *
 */
public class MainMenuSwt extends PBSwt {

	private static final int COLS = 2;

	/**
	 * タイトル
	 */
	private static final String TITLE = Msg.getMainMenu();

	/**
	 * ウィンドウ幅
	 */
	static final int WINDOW_WIDTH = 410;

	/**
	 * ウィンドウ高さ
	 */
	static final int WINDOW_HEIGTH = 350;

	/**
	 * ボタンの幅
	 */
	static final int BUTTON_WIDTH = WINDOW_WIDTH;

	/**
	 * ボタン高さ
	 */
	static final int BUTTON_HEIGTH = 50;

	static final String[] GROUPS = {Msg.getMainmenuGroupManageData(), Msg.getMainmenuGroupInputGame(),
     Msg.getMainmenuGroupAnalyzeTeam(), Msg.getMainmenuGroupAnalyzePlayer(), 
     Msg.getMainmenuGroupElse()};
	static final String[][] MENU_LABELS = {
		{Msg.getTeamManage(), Msg.getPlayerManage()}, // データ管理
		{Msg.getOfficialGameInput(), Msg.getGameManage()}, // 試合入力
		{Msg.getAnalyzeTeamplayPerGame()}, // チーム分析
		{Msg.getAnalyzePlayPerPlayer(), Msg.getPlayRanking(), Msg.getPlayRankingChart()}, // 選手プレー分析
		// FIXME 選手別分析 選手を選択してその選手のプレー（時系列）を分析
		{Msg.getVersionInfo(), Msg.getHelp(), Msg.getExit()} // その他
	};
	
	static final Object[][] MENU_SWTS = {
		{TeamListSwt.class, PlayerListSwt.class}, // データ管理
		{OfficialGameStartSwt.class, GameListSwt.class}, // 試合入力
		{AnalayzeTeamParGameSwt.class}, // チー分析
		{AnalayzePlayerSwt.class, AnalayzeRankingSwt.class, ChartAnalayzeRankingSwt.class}, // 選手プレー分析
		{VersionInfoSwt.class, CMD.HELP, CMD.EXIT} // その他
	};

	private static final Rectangle rect = new Rectangle(0, 0, 80, 30);
	
	/**
	 * コンストラクタ
	 */
	public MainMenuSwt() {
		super();
		initialize();
	}	
	
	/**
	 * 初期化
	 */
	private void initialize() {
		createSShell(TITLE, WINDOW_WIDTH, WINDOW_HEIGTH);

		for (int i = 0; i < GROUPS.length; i++) {
			// グループ作成
			Group g = createGroupShadowEtchedOut_FILL(GROUPS[i], COLS, true);

			for (int j = 0; j < MENU_LABELS[i].length; j++) {
				String label = MENU_LABELS[i][j];
				Object cmd = MENU_SWTS[i][j];
				if (cmd instanceof String) {
					addSimpleButton(g, label, (String)cmd);
				} else  {
					addShowWindowButton(g, label, (Class)cmd);
				}
			}
		}
	}

	/**
	 * swt_cls を表示するボタンを追加
	 * @param label ボタンラベル
	 * @param swt_cls 表示ラベル
	 */
	private void addShowWindowButton(Composite comp, String label, Class swt_cls) {
		Button button = addSimpleButton(comp, label);
		button.addSelectionListener(new MenuSelectAdapter(swt_cls));
	}
	
	/**
	 * 終了選択時
	 */
	public void cmdExit() {
		this.sShell.close();
	}
	
	/**
	 * ヘルプ選択時.IDVollayのHPにジャンプ
	 */
	public void cmdHelp() {
		try {
			Runtime.getRuntime().exec("explorer " + Msg.getHelpUrl());
		} catch (IOException e) {
			// TODO 自動生成された catch ブロック
			e.printStackTrace();
		}
	}
	
	/**
	 * メニューボタン選択時のイベントハンドラ
	 * @author amonden
	 *
	 */
	class MenuSelectAdapter extends SelectionAdapter {

		/**
		 * SWT画面クラス
		 */
		private Class pbswt_class;

		/**
		 * コンストラクタ
		 * @param pbswt_class
		 */
		public MenuSelectAdapter(Class pbswt_class) {
			super();
			this.pbswt_class = pbswt_class;
		}

		/* (非 Javadoc)
		 * @see org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt.events.SelectionEvent)
		 */
		public void widgetSelected(SelectionEvent e) {
			PBSwt swt;
			try {
				swt = (PBSwt) pbswt_class.newInstance();
				swt.show();
			} catch (InstantiationException e1) {
				e1.printStackTrace();
			} catch (IllegalAccessException e1) {
				e1.printStackTrace();
			} catch (Exception e1) {
				e1.printStackTrace();
			}
		}
	}
	
	/**
	 * main
	 * @param args
	 */
	public static void main(String[] args) {
		/* Before this is run, be sure to set up the following in the launch configuration 
		 * (Arguments->VM Arguments) for the correct SWT library path. 
		 * The following is a windows example:
		 * -Djava.library.path="installation_directory\plugins\org.eclipse.swt.win32_3.0.0\os\win32\x86"
		 */
		
		PBSwt splash = new SplashSwt();
		splash.show(false);
		DBManager.init();// DB初期化
		splash.cmdOk();
		
		new MainMenuSwt().show();
		
		DBManager.close();
	}	
	
}
