package jp.co.powerbeans.vbscore.swt;

import jp.co.powerbeans.common.swt.ChkConvSwt;
import jp.co.powerbeans.vbscore.CMD;
import jp.co.powerbeans.vbscore.Msg;
import jp.co.powerbeans.vbscore.db.DBManager;
import jp.co.powerbeans.vbscore.db.DBUtil;
import jp.co.powerbeans.vbscore.logic.ScoreMgr;
import jp.co.powerbeans.vbscore.model.Player;

import org.eclipse.swt.widgets.Table;

/**
 * プレー中メンバー変更
 * @author amonden
 *
 */
public class MemberChangeSwt extends PBSwt {

	/**
	 * プレー中プレイヤーTable
	 */
	private Table playingTable;
	/**
	 * 控えプレイヤーTable
	 */
	private Table subPlayerTable;

	/**
	 * チームID
	 */
	private int teamId;

	/**
	 * プレー中プレイヤー配列
	 */
	private Player[] playingPlayers;
	/**
	 * 控えプレイヤー配列
	 */
	private Player[] subPlayer;
	/**
	 * outプレイヤー(ベンチへ下がった)
	 */
	private int outPlayerId;
	/**
	 * inプレイヤー(コートに入った)
	 */
	private int inPlayerId;

	/**
	 * ウィンドウ幅
	 */
	static final int WINDOW_WIDTH = 300;
	/**
	 * ウィンドウ高さ
	 */
	static final int WINDOW_HEIGTH = 400;

	/**
	 * タイトル
	 */
	private static final String TITLE = Msg.getMemberChange();
	/**
	 * テーブル列名
	 */
	private static final String[] TABLE_COLS = {Msg.getId(), Msg.getFullname(), Msg.getSharp()};
	/**
	 * テーブル表示プロパティ名
	 */
	private static final String[] TABLE_MODEL_COLS = new String[]{"playerId", "playerName", "stdNumber"};
	/**
	 * テーブル列幅
	 */
	private static final int[] TABLE_COL_WIDTHS = {30,100, 100};

	/**
	 * コンストラクタ
	 * @param teamId チームID
	 * @param players 選手ID
	 */
	public MemberChangeSwt(int teamId, Player[] players) {
		super();
		this.teamId = teamId;
		this.playingPlayers = players;
		initialize();
	}	
	
	/**
	 * 初期化
	 */
	private void initialize() {
		createSShell(TITLE, WINDOW_WIDTH, WINDOW_HEIGTH, true);
		setGridLayout(2);
		createItems();
	}

	/**
	 * Item生成
	 */
	private void createItems() {
		setHorizontalSpan(addLabel_left(Msg.getSelectEachPlayersAndClickOk()), 2);

		setHorizontalSpan(addLabel_left(Msg.getPlayingPlayer()), 2);
		createPlayingTable();
		
		setHorizontalSpan(addLabel_left(Msg.getObserverPlayer()), 2);
		createSubPlayerTable();
		
		addOKButton();
		addCancelButton();
	}

	/**
	 * 控えプレイヤー一覧table作成
	 */
	private void createSubPlayerTable() {
		if (subPlayerTable == null) {
			subPlayerTable = addMiniTable(TABLE_COLS, TABLE_COL_WIDTHS, 200);
			setHorizontalSpan(subPlayerTable, 2);
			setCmdToTableOnDoubleClick(this.subPlayerTable, CMD.OK);
			
			this.subPlayerTable.removeAll();
			this.subPlayer = ScoreMgr.getSubPlayers(this.teamId, this.playingPlayers);
			DBUtil.modelsToSwtTable(this.subPlayerTable, this.subPlayer, TABLE_MODEL_COLS);
		}
	}

	/**
	 * プレー中プレイヤー一覧table作成
	 */
	private void createPlayingTable() {
		if (playingTable == null) {
			playingTable = addMiniTable(TABLE_COLS, TABLE_COL_WIDTHS, 200);
			setHorizontalSpan(playingTable, 2);
			setCmdToTableOnDoubleClick(this.playingTable, CMD.OK);
			
			this.playingTable.removeAll();
			DBUtil.modelsToSwtTable(this.playingTable, this.playingPlayers, TABLE_MODEL_COLS);
		}
	}
	
	/* (非 Javadoc)
	 * @see jp.co.powerbeans.vbscore.swt.PBSwt#cmdOk()
	 */
	public void cmdOk() {
		outPlayerId = ChkConvSwt.getSelectId(this.playingTable);
		inPlayerId = ChkConvSwt.getSelectId(this.subPlayerTable);
		
		// 両テーブルを選択済みなら入れ替える
		for (int i = 0; i < this.playingPlayers.length; i++) {
			if (playingPlayers[i].getPlayerId() == outPlayerId) {
				playingPlayers[i] = (Player) DBManager.findByPrimaryKey(Player.class, inPlayerId);
				break;
			}
		}
		super.cmdOk();
	}

	/**
	 * プレー中プレイヤーリスト取得
	 * @return プレー中プレイヤー配列
	 */
	public Player[] getNewMyplayers() {
		return this.playingPlayers;
	}

	/**
	 * inプレイヤーのIDを取得
	 * @return inPlayerId を戻します。
	 */
	public int getInPlayerId() {
		return inPlayerId;
	}

	/**
	 * outプレイヤーのIDを取得
	 * @return outPlayerId を戻します。
	 */
	public int getOutPlayerId() {
		return outPlayerId;
	}
}
