package jp.co.powerbeans.vbscore.swt;


import jp.co.powerbeans.vbscore.Msg;
import jp.co.powerbeans.vbscore.MsgSwt;
import jp.co.powerbeans.vbscore.db.DBManager;
import jp.co.powerbeans.vbscore.logic.ScoreMgr;
import jp.co.powerbeans.vbscore.model.Game;
import jp.co.powerbeans.vbscore.model.GameSet;
import jp.co.powerbeans.vbscore.model.Team;
import jp.co.powerbeans.vbscore.swt.parts.PlayerListCoartComposit;

import org.eclipse.swt.widgets.Button;

/**
 * 公式戦スタメン入力画面
 * @author amonden
 * 
 */
public class OfficialGameSetStartSwt extends PBSwt {

	/**
	 * 試合
	 */
	private Game game;

	/**
	 * セット
	 */
	private GameSet set;

	/**
	 * 自チーム
	 */
	private Team myTeam;

	/**
	 * 対戦チーム
	 */
	private Team vsTeam;

	/**
	 * サーブ開始チームID
	 */
	private Button[] serveStartTeamID;

	/**
	 * 自チームスタメンコート
	 */
	private PlayerListCoartComposit myTeamListCoart;

	/**
	 * 対戦チームスタメンコート
	 */
	private PlayerListCoartComposit vsTeamListCoart;


	/**
	 * ウィンドウ幅
	 */
	static final int WINDOW_WIDTH = 520;

	/**
	 * ウィンドウ高さ
	 */
	static final int WINDOW_HEIGTH = 500;

	/**
	 * タイトル
	 */
	private static final String TITLE = Msg.getInputStatingMember();

	// private static final String[] MENU_LABELS = {"編集(&E) ","追加(&A)", "削除(&D)
	// "};
	// private static final String[] MENU_CMDS = {CMD.EDIT, CMD.ADD, CMD.DEL};

	/**
	 * コンストラクタ
	 * @param game 対象試合
	 * @param set 対象セット
	 */
	public OfficialGameSetStartSwt(Game game, GameSet set) {
		super();
		MsgSwt.warn(Msg.getSelectPlayerOrderbyServe());
		this.game = game;
		this.set = set;
		initialize();
	}

	/**
	 * 初期化
	 */
	private void initialize() {
		loadData();
		createSShell(TITLE, WINDOW_WIDTH, WINDOW_HEIGTH, true);
		setGridLayout(2);
//		createComposit();
		// createMenu();
		createItems();
	}

	/**
	 * マスタロード
	 */
	private void loadData() {
		// チームロード
		this.myTeam = (Team) DBManager.findByPrimaryKey(Team.class, this.game.getMyTeamId());
		this.vsTeam = (Team) DBManager.findByPrimaryKey(Team.class, this.game.getVsTeamId());
		
	}

	/**
	 * 項目作成
	 */
	private void createItems() {
		
		addLabel_left(Msg.getOwnTeam() + " " + this.myTeam.getTeamName());
		addLabel_left(Msg.getVsPlayer() + " " + this.vsTeam.getTeamName());
		
		this.serveStartTeamID = addRadioButtons("serveStartTeamID", 
				new String[]{Msg.getServeHas(), Msg.getServeHas()},
				new int[]{this.game.getMyTeamId(), this.game.getVsTeamId()});
		selectItem(this.serveStartTeamID[0]);
		
//		// 選手リスト,コート
		this.myTeamListCoart = new PlayerListCoartComposit(this.sShell, this.myTeam);
		this.vsTeamListCoart = new PlayerListCoartComposit(this.sShell, this.vsTeam);
		
		addOKButton();
		addCancelButton();
	}

	/* (非 Javadoc)
	 * @see jp.co.powerbeans.vbscore.swt.PBSwt#cmdOk()
	 */
	public void cmdOk() {
		
		// 必須項目チェック
		if (!this.myTeamListCoart.isMaxPlayer() || !this.vsTeamListCoart.isMaxPlayer()) {
			MsgSwt.warnSelectPlayerMax();
			return;
		}
		
		// Set を保存
		GameSet copyset = (GameSet) copyControlToMode(GameSet.class);
		// サーブ権
		this.set.setServeStartTeamID(copyset.getServeStartTeamID());
		// スタメンプレイヤー
		ScoreMgr.copyPlayerToSet(this.myTeamListCoart.getPlayerList(), "myPlayerId", this.set);
		ScoreMgr.copyPlayerToSet(this.vsTeamListCoart.getPlayerList(), "vsPlayerId", this.set);
		ScoreMgr.copyPlayerToSet(this.myTeamListCoart.getPlayerList(), "myPlayingPlayerId", this.set);
		
		DBManager.update(this.set);
		
		// Game を保存
		this.game.setGameStatus(Game.STATUS_PLAYING);
		DBManager.update(this.game);
		
		// 第1セット入力画面へ
    super.cmdOk();
    
		new OfficialGameInputSwt(game, set).show();
	}

}
