package jp.co.powerbeans.vbscore.swt.parts;

import java.util.Date;

import jp.co.powerbeans.common.swt.ChkConvSwt;
import jp.co.powerbeans.common.swt.PBControlUtil;
import jp.co.powerbeans.vbscore.CMD;
import jp.co.powerbeans.vbscore.Msg;
import jp.co.powerbeans.vbscore.db.DBManager;
import jp.co.powerbeans.vbscore.model.GameTeams;
import jp.co.powerbeans.vbscore.model.Team;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;


/**
 * チーム検索用Composit.
 * チーム検索条件と検索結果を一覧表示する
 * @author amonden
 */
public class TeamSearchGroup implements SelectionListener {

	private static final int COLS = 5;
	private Combo teamCombo;
	private Text fromDate;
	private Text toDate;
	private GameMiniTableComposit gameTable;
	private Group group;
	private Button searchButton;

	/**
	 * コンストラクタ
	 * @param shell 親shell
	 */
	public TeamSearchGroup(Shell shell) {
		this(shell,  Msg.getSearchGame());
	}
	
	/**
	 * コンストラクタ
	 * @param shell 親shell
	 * @param team チーム
	 */
	public TeamSearchGroup(Shell shell, String label) {
		this.group = PBControlUtil.createGroupChadowEthedOut_BEGIN(shell, label, COLS, false);
		
//		this.group.setLayout(new GridLayout(COLS, true));
//		GridData compGrid = new GridData();
//		compGrid.horizontalAlignment = GridData.BEGINNING;
//		compGrid.verticalAlignment = GridData.FILL;
//		compGrid.grabExcessHorizontalSpace = false;
//		compGrid.grabExcessVerticalSpace = false;
//		compGrid.heightHint = 300;
//    this.group.setLayoutData(compGrid);
		
		// チーム選択コンボ
		PBControlUtil.createLabel_left(this.group, Msg.getTargetTeam());
		this.teamCombo = PBControlUtil.createComboBoxReadOnly(this.group, SWT.LEFT);
		DBManager.findByAllToSwtComboBox(teamCombo, Team.class, "teamName");
		PBControlUtil.selectTop(this.teamCombo);
		
		PBControlUtil.createLabelEmpty(this.group, COLS - 2);
		
		// 日付
		PBControlUtil.createLabel_left(this.group, Msg.getTargetGameDateSpan());
		this.fromDate = PBControlUtil.addTextBox(this.group);
		PBControlUtil.createLabel_hvcenter(this.group, Msg.getChilda());
		this.toDate = PBControlUtil.addTextBox(this.group);
//		PBControlUtil.createLabelEmpty(this.group, 2);

		// 検索ボタン(TODO 自動計算にする?)
		this.searchButton = PBControlUtil.createSimpleButton(this.group, Msg.getSearch(), CMD.SEARCH);
		this.searchButton.addSelectionListener(this);

		// 検索結果テーブル
		createGameTable();
	}
	
	/**
	 * gameTable作成
	 */
	private void createGameTable() {
		if (this.gameTable == null) {
			this.gameTable = new GameMiniTableComposit(this.group, COLS);
//			this.gameTable.setHorizontalSpan(COLS);
		}
	}

	/* (非 Javadoc)
	 * @see org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt.events.SelectionEvent)
	 */
	public void widgetSelected(SelectionEvent arg0) {
		// 検索ボタン選択時
		// 検索条件取得
		int team_id = Integer.parseInt(ChkConvSwt.getSelectObjectPK(this.teamCombo));
		Date from_dt = ChkConvSwt.getDate(this.fromDate.getText());
		Date to_dt = ChkConvSwt.getDate(this.toDate.getText());

		// 検索開始
//		// 1. 全プレーのランキング
//		PlayerRanking[][] ta = ScoreMgr.analyzePlayerRanking(team_id, from_dt, to_dt);
		
		// 2. 対象試合更新
		this.gameTable.updateByDate(team_id, from_dt, to_dt);
		
//		// 更新
//		updateTable(ta);
//
//		
		
	}
	
//	/**
//	 * 更新テーブル
//	 * @param ta プレイヤーランキング
//	 */
//	private void updateTable(PlayerRanking[][] ta) {
//		this.ga.removeAll();
//		addTable(ta);
//	}
//
//	/**
//	 * ランキングをtableに追加
//	 * @param ta プレイヤーランキング
//	 */
//	private void addTable(PlayerRanking[][] ta) {
//		DBUtil.modelsToSwtTable(table, createTableData(ta));
//	}

	public void widgetDefaultSelected(SelectionEvent arg0) {
	}

	/**
	 * 試合が選択されているかどうか
	 * @return true 選択済み, false 未選択
	 */
	public boolean isSelectGame() {
		return this.gameTable.getTable().getSelectionCount() > 0;
	}

	/**
	 * 選択試合を取得
	 * @return
	 */
	public GameTeams[] getSelectGames() {
		return (GameTeams[]) ChkConvSwt.getSelectObjects(this.gameTable.getTable());
	}

	/**
	 * 選択チームを取得
	 * @return
	 */
	public Team getSelectTeam() {
		return (Team) ChkConvSwt.getSelectObject(this.teamCombo);
	}
	
	/**
	 * 検索開始日取得
	 * @return
	 */
	public String getFromDate() {
		return this.fromDate.getText();
	}
	
	/**
	 * 終了日取得
	 * @return
	 */
	public String getToDate() {
		return this.toDate.getText();
	}
}
